.. _explanation:

Explanation
===========

Explanations provide a wider perspective of Charmcraft. They aid in understanding the
concepts and relationships of Charmcraft as a complete system.


Cryptography
------------

Charmcraft and its external libraries use cryptographic tools for fetching files,
communicating with local processes, and storing user credentials.

- :ref:`Cryptographic technology <explanation-cryptographic-technology>`


.. toctree::
    :maxdepth: 1
    :hidden:

    bases
    Cryptographic technology <cryptography>
